Installation - MindRoot 9.10.0 documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# Installation

If MindRoot is already installed and running, skip to LLM Plugin Installation. If using pre-configured MindRoot hosting, skip to LLM API Key.

Create and enter a directory for your mindroot instance:

`mkdir ~/mymindroot && cd ~/mymindroot`

Usually you need to create a python virtual environment:

`python -m venv .venv`

And activate:

`source .venv/bin/activate`

Then just install with pip:

`pip install mindroot`